plmm returns an object of the plmm class.
plmm(formula, random, h0, data, vc.method = "FC", nonpar.bws = "h.select",
poly.index = 1, iter = 20, scale.h = 1, epsilon = 0.003, lim.binning = 100,
hetero.prop = NULL, ...)formula consists of three parts: the response (the left hand side of ~), the fixed parametric component (between ~ and |), and the fixed nonparametric component (the right hand side of |).
h0 can be obtained using select.h0. h0 is optional; if omitted, select.h0 is called automatically to compute a set of bandwidths. The user can modify bandwidths in a list object created by select.h0 and pass the object to plmm.
data, the variables are taken from the environment plmm was called from.
hetero.prop specified.
nonpar.bws.
h.select or hcv, which include nbins, hstart and hend. See sm.options and hcv.
nonpar.bws, an alternative definition $N-p-tr(2SR-SRS^T)$ is applied with $R$ being the estimated correlation matrix of the data.plmm.plmm.select.h0.sm.regression. There are four methods for bandwidth selection: h.select calls h.select to execute cross validation (CV) using binning techniques; hcv calls hcv which implements the ordinary CV; GCV uses the generalized CV; and GCV.c performs generalized CV for correlated data. sm.regression, h.select and hcv are functions of the sm package.
When the nonparametric component is a function of two variables, optimization procedure selects one bandwidth that, multiplied by the standard deviations of those variables, minimizes the cross validation statistic. The user can further scale the bandwidths using scale.h.
epsilon is the value to determine the convergence of iterative estimation. For the $r$th iteration round, the absolute value of $(\sigma^{2}_{(r)}-\sigma^{2}_{(r-1)})/\sigma^{2}_{(r-1)}$ is calculated for each variance component. The iteration procedure ends when this absolute value of both variance components becomes smaller than epsilon.
select.h0, h.select, hcv, sm.options. data(plmm.data)
plmm(y0~x1+x2+x3|t1, random=cluster, data=plmm.data)
# heteroskedasticity proportionality x3
plmm(y1~x1+x2+x3|t1, random=cluster, data=plmm.data, vc.method="FChetero", hetero.prop=x3)
# nonparametric component of two covariates, t1 and t2
## Not run:
# plmm(y2~x1+x2+x3|t1+t2, random=cluster, data=plmm.data) ## End(Not run)
Run the code above in your browser using DataLab