plmm, and refit the model applying the weighted least squares procedure. wplmm returns an object of the wplmm class.
wplmm(object, heteroX, data, nonpar.bws = "h.select", poly.index = 1,
var.fun.bws = "ROT", var.fun.poly.index = 0, scale.h = 1, trim = 0.01,
lim.binning = 100, ...)plmm.wplmm was called.trim, they are set to this value. The default is 0.01.nonpar.bws.h.select or hcv, which include nbins, hstart and hend. See sm.options and hcv. trim have been set to the value of trim.nonpar.bws, alternative definition $N-p-tr(2SR-SRS^T)$ is applied with $R$ being the estimated correlation matrix of the data.wplmm.wplmm.select.h0 underlying the plmm that yielded the object.plmm that yielded the object.h.select and hcv, respectively, which are functions of the sm package; ROT selects the bandwidths for heteroskedasticity conditioning variable $w$ by $sd(w)N^{-1/(4+q)}$ where $q$ is the number of the conditioning variables (1 or 2) and $N$ is the sample size.
plmm, h.select, hcv, sm.options.
data(plmm.data)
model <- plmm(y1~x1+x2+x3|t1, random=cluster, data=plmm.data)
model2 <- wplmm(model, heteroX=x3, data=plmm.data)
summary(model2)
Run the code above in your browser using DataLab